diff avcodec.h @ 7002:92c74bbdf4fb libavcodec

add esa/dia compat me options and new tesa for libx264
author bcoudurier
date Thu, 05 Jun 2008 01:57:35 +0000
parents 91a3324f4abc
children c29f78dbe1bd
line wrap: on
line diff
--- a/avcodec.h	Wed Jun 04 00:56:36 2008 +0000
+++ b/avcodec.h	Thu Jun 05 01:57:35 2008 +0000
@@ -31,7 +31,7 @@
 
 #define LIBAVCODEC_VERSION_MAJOR 51
 #define LIBAVCODEC_VERSION_MINOR 57
-#define LIBAVCODEC_VERSION_MICRO  1
+#define LIBAVCODEC_VERSION_MICRO  2
 
 #define LIBAVCODEC_VERSION_INT  AV_VERSION_INT(LIBAVCODEC_VERSION_MAJOR, \
                                                LIBAVCODEC_VERSION_MINOR, \
@@ -374,6 +374,7 @@
     ME_HEX,         ///< hexagon based search
     ME_UMH,         ///< uneven multi-hexagon search
     ME_ITER,        ///< iterative search
+    ME_TESA,        ///< thresholded exhaustive search algorithm
 };
 
 enum AVDiscard{
@@ -840,7 +841,7 @@
     /**
      * Motion estimation algorithm used for video coding.
      * 1 (zero), 2 (full), 3 (log), 4 (phods), 5 (epzs), 6 (x1), 7 (hex),
      * 8 (umh), 9 (iter) [7, 8 are x264 specific, 9 is snow specific]
      * - encoding: MUST be set by user.
      * - decoding: unused
      */
@@ -840,7 +841,7 @@
      * Motion estimation algorithm used for video coding.
      * 1 (zero), 2 (full), 3 (log), 4 (phods), 5 (epzs), 6 (x1), 7 (hex),
-     * 8 (umh), 9 (iter) [7, 8 are x264 specific, 9 is snow specific]
+     * 8 (umh), 9 (iter), 10 (tesa) [7, 8, 10 are x264 specific, 9 is snow specific]
      * - encoding: MUST be set by user.
      * - decoding: unused